@@ -4,18 +4,32 @@ import os
 import time
 from datetime import timedelta
 
-from notedata.tables import SqliteTable
+from notedrive.lanzou import LanZouCloud
+from notedrive.tables import SqliteTable
 
 
 class AutoSaveDetail(SqliteTable):
-    def __init__(self, db_path=None, save_freq='d', ms=False, save_key=None, save_with_clear=True, *args, **kwargs):
+    def __init__(self,
+                 db_path=None,
+                 save_freq='d',
+                 fid=-1,
+                 ms=False,
+                 save_key=None,
+                 save_with_clear=True,
+                 *args,
+                 **kwargs):
         if db_path is None:
             db_path = os.path.abspath(os.path.dirname(__file__)) + '/data/coin.db'
+
+        super(AutoSaveDetail, self).__init__(db_path=db_path, *args, **kwargs)
+
         self.ms = ms
+        self.fid = fid
         self.save_key = save_key
         self.save_freq = save_freq
         self.save_with_clear = save_with_clear
-        self.save_time_unix = datetime.datetime.now()
+        self.last_finish_save_unix = datetime.datetime.now()
+        self.last_temp_save_unix = datetime.datetime.now()
 
         if self.save_freq in ('d', 'D', 'Day', 'day'):
             self.save_freq = 'd'
@@ -27,28 +41,44 @@ class AutoSaveDetail(SqliteTable):
             self.save_freq = 'y'
         else:
             self.save_freq = 'd'
-        super(AutoSaveDetail, self).__init__(db_path=db_path, *args, **kwargs)
+
+        self.path_root = os.path.join(os.path.dirname(self.db_path), self.table_name)
+        if not os.path.exists(self.path_root):
+            os.makedirs(self.path_root)
+
+        self.downer = LanZouCloud()
+        self.downer.ignore_limits()
+        self.downer.login_by_cookie()
 
     def auto_save(self):
+        """
+        数据保存，分两种，
+        一种是数据已经准备完成，上传云端,每天凌晨1点以后保存一次
+        另一种是保存中间结果，每隔3个小时保存一次
+        """
         time_unix = datetime.datetime.now()
+
+        is_finish_save = False
+
         if self.save_freq in ('d', 'D', 'Day', 'day'):
-            if self.save_time_unix.day != time_unix.day and time_unix.hour > 1:
-                self._save(now=self.save_time_unix, pop=self.save_with_clear)
-                self.save_time_unix = time_unix
+            is_finish_save = self.last_finish_save_unix.day != time_unix.day and time_unix.hour >= 1
         elif self.save_freq in ('m', 'M', 'mon', 'Mon', 'month', 'Month'):
-            if self.save_time_unix.month != time_unix.month and time_unix.hour > 1:
-                self._save(now=self.save_time_unix, pop=self.save_with_clear)
-                self.save_time_unix = time_unix
+            is_finish_save = self.last_finish_save_unix.month != time_unix.month and time_unix.hour >= 1
         elif self.save_freq in ('m', 'M', 'mon', 'Mon', 'month', 'Month'):
-            if self.save_time_unix.year != time_unix.year and time_unix.hour > 1:
-                self._save(now=self.save_time_unix, pop=self.save_with_clear)
-                self.save_time_unix = time_unix
+            is_finish_save = self.last_finish_save_unix.year != time_unix.year and time_unix.hour >= 1
+
+        is_temp_save = abs(self.last_temp_save_unix.hour - time_unix.hour) >= 3
+        if is_finish_save:
+            self._save(now=self.last_finish_save_unix, pop=self.save_with_clear)
+            self.last_finish_save_unix = time_unix
+            self.downer.sync_files(self.path_root, folder_id=self.fid, overwrite=True, remove_local=True)
+        elif is_temp_save:
+            self._save(pop=False)
+            self.last_temp_save_unix = time_unix
 
     def _save(self, pop=None, now=None):
         now = now or datetime.datetime.now()
-        path_root = os.path.join(os.path.dirname(self.db_path), self.table_name)
-        if not os.path.exists(path_root):
-            os.makedirs(path_root)
+
         name = self.table_name
         if self.save_freq in ('d', 'D', 'Day', 'day'):
             fmt = "%Y%m%d"
@@ -68,7 +98,7 @@ class AutoSaveDetail(SqliteTable):
             condition = None
             condition2 = None
 
-        path = '{}/{}-{}.csv'.format(path_root, name, self.save_time_unix.strftime(fmt))
+        path = '{}/{}-{}.csv'.format(self.path_root, name, self.last_finish_save_unix.strftime(fmt))
 
         self.to_csv(condition=condition, path=path, index=None)
         if pop:
@@ -119,7 +149,9 @@ class TradeDetail(AutoSaveDetail):
                 os.path.dirname(__file__)) + '/data/coin.db'
 
         super(TradeDetail, self).__init__(db_path=db_path, ms=True,
-                                          save_key='ts', table_name=table_name, *args, **kwargs)
+                                          fid=3359101,
+                                          save_key='ts',
+                                          table_name=table_name, *args, **kwargs)
         self.columns = ['trade_id', 'amount', 'price', 'ts', 'direction']
 
     def create(self):
@@ -144,6 +176,7 @@ class SymbolInfo(AutoSaveDetail):
         super(SymbolInfo, self).__init__(db_path=db_path,
                                          table_name=table_name,
                                          save_freq='y',
+                                         fid=3360754,
                                          save_key='',
                                          save_with_clear=False,
                                          *args, **kwargs)
@@ -223,29 +256,35 @@ class KlineDetail(AutoSaveDetail):
 
 class Kline1MinDetail(KlineDetail):
     def __init__(self, table_name='kline_1min', db_path=None, *args, **kwargs):
-        super(Kline1MinDetail, self).__init__(table_name=table_name, db_path=db_path, *args, **kwargs)
+        super(Kline1MinDetail, self).__init__(table_name=table_name, fid=3359096, db_path=db_path, *args, **kwargs)
 
 
 class Kline5MinDetail(KlineDetail):
     def __init__(self, table_name='kline_5min', db_path=None, *args, **kwargs):
-        super(Kline5MinDetail, self).__init__(table_name=table_name, db_path=db_path, *args, **kwargs)
+        super(Kline5MinDetail, self).__init__(table_name=table_name, fid=3359092, db_path=db_path, *args, **kwargs)
 
 
 class Kline15MinDetail(KlineDetail):
     def __init__(self, table_name='kline_15min', db_path=None, *args, **kwargs):
-        super(Kline15MinDetail, self).__init__(table_name=table_name, db_path=db_path, *args, **kwargs)
+        super(Kline15MinDetail, self).__init__(table_name=table_name,
+                                               fid=3359095,
+                                               db_path=db_path,
+                                               *args, **kwargs)
 
 
 class Kline30MinDetail(KlineDetail):
     def __init__(self, table_name='kline_30min', db_path=None, *args, **kwargs):
         super(Kline30MinDetail, self).__init__(table_name=table_name,
                                                db_path=db_path,
+                                               fid=3359097,
                                                save_freq='m', *args, **kwargs)
 
 
 class Kline60MinDetail(KlineDetail):
     def __init__(self, table_name='kline_60min', db_path=None, *args, **kwargs):
-        super(Kline60MinDetail, self).__init__(table_name=table_name, db_path=db_path,
+        super(Kline60MinDetail, self).__init__(table_name=table_name,
+                                               fid=3360759,
+                                               db_path=db_path,
                                                save_freq='m', *args, **kwargs)
 
 
@@ -253,6 +292,7 @@ class Kline4HourDetail(KlineDetail):
     def __init__(self, table_name='kline_4hour', db_path=None, *args, **kwargs):
         super(Kline4HourDetail, self).__init__(table_name=table_name,
                                                save_freq='m',
+                                               fid=3359094,
                                                db_path=db_path, *args, **kwargs)
 
 
@@ -260,6 +300,7 @@ class Kline1DayDetail(KlineDetail):
     def __init__(self, table_name='kline_1day', db_path=None, *args, **kwargs):
         super(Kline1DayDetail, self).__init__(table_name=table_name,
                                               db_path=db_path,
+                                              fid=3359093,
                                               save_freq='y', *args, **kwargs)
 
 
@@ -268,6 +309,7 @@ class Kline1MonDetail(KlineDetail):
         super(Kline1MonDetail, self).__init__(table_name=table_name,
                                               db_path=db_path,
                                               save_freq='y',
+                                              fid=3359099,
                                               save_with_clear=False,
                                               *args, **kwargs)
 
@@ -277,6 +319,7 @@ class Kline1WeekDetail(KlineDetail):
         super(Kline1WeekDetail, self).__init__(table_name=table_name,
                                                db_path=db_path,
                                                save_freq='y',
+                                               fid=3359098,
                                                save_with_clear=False,
                                                *args, **kwargs)
 
@@ -286,5 +329,6 @@ class Kline1YearDetail(KlineDetail):
         super(Kline1YearDetail, self).__init__(table_name=table_name,
                                                db_path=db_path,
                                                save_freq='y',
+                                               fid=3359091,
                                                save_with_clear=False,
                                                *args, **kwargs)
