@@ -8,13 +8,15 @@ from notecoin.okex.database.client import OkexClientAccountBalance
 from notecoin.okex.database.websocket import OkexWebsocketChannels
 from notecoin.okex.websocket.channel import PublicChannel
 from notecoin.okex.websocket.connect import PublicConnect
-from notecoin.okex.websocket.handle import PublicTickers
+from notecoin.okex.websocket.handle import PublicTickers, ResponseHandel
 
 
 class WebsocketService(APIRouter):
     def __init__(self, connect: BaseConnect = None, prefix='/websocket', *args, **kwargs):
         self.connect = connect or PublicConnect(channels=[PublicChannel.public_tickers().to_json()])
         self.connect.add_handle(PublicTickers())
+        self.connect.add_handle(ResponseHandel())
+        
         super(WebsocketService, self).__init__(prefix=prefix, *args, **kwargs)
         add_api_routes(self)
         self.connect.run()
