@@ -16,7 +16,7 @@ class BaseHandle:
             return False
 
         channel = data['arg']['channel']
-        if channel in self.channels:
+        if len(self.channels) == 0 or channel in self.channels:
             return self.handle(data)
 
     def handle(self, data) -> bool:
@@ -38,3 +38,22 @@ class PublicTickers(BaseHandle):
             logging.error(f"error:{e}")
             return False
         return True
+
+
+class ResponseHandel(BaseHandle):
+    def __init__(self, *args, **kwargs):
+        create_all()
+        super(ResponseHandel, self).__init__(channels=['tickers'], *args, **kwargs)
+
+    def handle(self, data) -> bool:
+        try:
+            res = {
+                "channel": data['arg']['channel'],
+                "response": str(data)
+            }
+            session.merge(OkexSocketPublicTickers(**res))
+            session.commit()
+        except Exception as e:
+            logging.error(f"error:{e}")
+            return False
+        return True
